==> haskell-lucid-2.11.20250303-50.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lucid
version:              2.11.20250303
visibility:           public
id:                   lucid-2.11.20250303-mIfSyYQWD8L0pbvgCqca8
key:                  lucid-2.11.20250303-mIfSyYQWD8L0pbvgCqca8
license:              BSD-3-Clause
copyright:            2014-2021 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  f93ea700e68f8e030edd8e47ce69fa0d
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lucid-2.11.20250303
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lucid-2.11.20250303
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lucid-2.11.20250303
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lucid
hs-libraries:         HSlucid-2.11.20250303-mIfSyYQWD8L0pbvgCqca8
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.11.20250303-51-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lucid
version:              2.11.20250303
visibility:           public
id:                   lucid-2.11.20250303-2DU0tzsivWAatyw5ZOVax
key:                  lucid-2.11.20250303-2DU0tzsivWAatyw5ZOVax
license:              BSD-3-Clause
copyright:            2014-2021 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  ad73e55af2314262e417b6f4a5ffc41e
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lucid-2.11.20250303
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lucid-2.11.20250303
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lucid-2.11.20250303
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lucid
hs-libraries:         HSlucid-2.11.20250303-2DU0tzsivWAatyw5ZOVax
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
